@@ -12,7 +12,7 @@ import stat
 import sys
 
 __author__ = "Florian Leitner <florian.leitner@gmail.com>"
-__version__ = "4"
+__version__ = "5"
 ### PROGRESS BAR ###
 
 
@@ -90,7 +90,7 @@ class ProgressBar(object):
       heading: [=========>           21%                    ]
     """
 
-    def __init__(self, title=None, min_value=0, max_value=100, offset=0,
+    def __init__(self, title: str="", min_value=0, max_value=100, offset=0,
                  total_width=80, stream=sys.stderr):
         """
         Initialize a new progress bar.
@@ -109,7 +109,7 @@ class ProgressBar(object):
         self.prog_bar = None   # stores the latest progress bar string
         self.arrow = None      # stores the latest arrow of the bar
         self.percent = ""      # stores the latest percentage value string
-        self.title = title + ": " if title else ""
+        self.title = title + ": " if len(title) else ""
         if max_value < min_value:
             max_value = min_value
         self.min = min_value
@@ -174,7 +174,7 @@ class ProgressBar(object):
 
         if percent == self.percent:
             # if we are still at the same percentage, just return the old bar
-            return "%s%s" % (" " * self.offset, self.prog_bar)
+            return "%s%s%s" % (" " * self.offset, self.title, self.prog_bar)
         else:
             self.percent = percent
 
@@ -182,7 +182,7 @@ class ProgressBar(object):
             # if the width is really small, the "bar" is only an integer
             # without most of the fancy stuff
             self.prog_bar = "%3i" % int(percent)
-            return "%s%s" % (" " * self.offset, self.prog_bar)
+            return "%s%s%s" % (" " * self.offset, self.title, self.prog_bar)
 
         if arrow != self.arrow:
             # (Re-) Build the progress bar if the arrow length has changed
@@ -213,7 +213,7 @@ class ProgressBar(object):
         Return the latest progress bar string defined by the last
         ``updateAmount()`` call.
         """
-        return str(self.prog_bar)
+        return self.prog_bar
 
     def __call__(self, value):
         """
@@ -245,7 +245,7 @@ def InitBar(title: str=None, size: int=100, offset: int=2,
     :param stream: to print the progress bar an (default: STDERR)
     """
     width = TerminalSize()[0]
-    pbar = ProgressBar(title, max_value=size, offset=offset,
+    pbar = ProgressBar(title=title, max_value=size, offset=offset,
                        total_width=width, stream=stream)
     return pbar
 
